@@ -58,25 +58,71 @@ class TestConvertUnit(pikzie.TestCase):
 hotshotline_testdata_path = './test/hotshot.prof'
 hotshot_testdata_path = './test/hot.prof'
 cprof_testdata_path = './test/cprof.prof'
+prof_testdata_path = './test/less.profile'
+less_cprof_testdata_path = './test/less.cprof'
+twenty_hotprof_testdata_path = './test/20funcs.hotprof'
+less_hotprof_testdata_path = './test/less.hotprof'
 
 
 class TestExecuteHtml(pikzie.TestCase):
 
+    def setup(self):
+        self.dirname = tempfile.mkdtemp()
+
+    def teardown(self):
+        shutil.rmtree(self.dirname)
+
     def test_cprofhtml(self):
         prof = p2h.Converter(cprof_testdata_path)
+        prof.output_dir = self.dirname
+        prof.printout('html')
+        self.assert_equal(True, True)
+
+    def test_profilehtml(self):
+        prof = p2h.Converter(prof_testdata_path)
+        prof.output_dir = self.dirname
         prof.printout('html')
         self.assert_equal(True, True)
 
     def test_hotshothtml(self):
         prof = p2h.Converter(hotshot_testdata_path)
+        prof.output_dir = self.dirname
         prof.printout('html')
         self.assert_equal(True, True)
 
     def test_hotshotlinehtml(self):
         prof = p2h.Converter(hotshotline_testdata_path)
+        prof.output_dir = self.dirname
         prof.printout('html')
         self.assert_equal(True, True)
 
+    def test_cprof_function_is_twenty_or_less(self):
+        prof = p2h.Converter(less_cprof_testdata_path)
+        prof.output_dir = self.dirname
+        prof.printout('html')
+        path = self.dirname + '/index.html'
+        self.assert_equal(True, os.path.exists(path))
+        path = self.dirname + '/index-all.html'
+        self.assert_equal(False, os.path.exists(path))
+
+    def test_hotshot_function_is_twenty(self):
+        prof = p2h.Converter(twenty_hotprof_testdata_path)
+        prof.output_dir = self.dirname
+        prof.printout('html')
+        path = self.dirname + '/index.html'
+        self.assert_equal(True, os.path.exists(path))
+        path = self.dirname + '/index-all.html'
+        self.assert_equal(False, os.path.exists(path))
+
+    def test_hotshot_function_is_less_or_twenty(self):
+        prof = p2h.Converter(less_hotprof_testdata_path)
+        prof.output_dir = self.dirname
+        prof.printout('html')
+        path = self.dirname + '/index.html'
+        self.assert_equal(True, os.path.exists(path))
+        path = self.dirname + '/index-all.html'
+        self.assert_equal(False, os.path.exists(path))
+
 
 class TestExecuteRaw(pikzie.TestCase):
 
@@ -102,7 +148,7 @@ class ColorMappingTest(pikzie.TestCase):
 
     def test_mapping_v1(self):
         ret = p2h.mapping_table(1, 1000)
-        self.assert_equal(ret, '#ccffcc')
+        self.assert_equal(ret, '#ffffff')
 
     def test_mapping_v2(self):
         ret = p2h.mapping_table(29, 1000)
@@ -122,7 +168,7 @@ class ColorMappingTest(pikzie.TestCase):
 
     def test_mapping_min(self):
         ret = p2h.mapping_table(0, 100)
-        self.assert_equal(ret, '#ccffcc')
+        self.assert_equal(ret, '#ffffff')
 
     def test_mapping_max(self):
         ret = p2h.mapping_table(100, 100)
@@ -130,7 +176,7 @@ class ColorMappingTest(pikzie.TestCase):
 
     def test_mapping_v1_float(self):
         ret = p2h.mapping_table(1., 1000.)
-        self.assert_equal(ret, '#ccffcc')
+        self.assert_equal(ret, '#ffffff')
 
     def test_mapping_v2_float(self):
         ret = p2h.mapping_table(10., 1000.)
@@ -150,7 +196,7 @@ class ColorMappingTest(pikzie.TestCase):
 
     def test_mapping_min_float(self):
         ret = p2h.mapping_table(0.0, 1000.0)
-        self.assert_equal(ret, '#ccffcc')
+        self.assert_equal(ret, '#ffffff')
 
     def test_mapping_max_float(self):
         ret = p2h.mapping_table(100., 100.)
